import regex
import torch
from torch.distributions.gamma import Gamma
from torch.distributions.categorical import Categorical
import numpy
import math
from typing import List
from kismet.personality.responses import responses as responses_


class Responder:
    def __init__(self, responses=responses_):
        self.categorical = Categorical(torch.ones(len(responses_)))
        self.responses = responses_

    def respond(self, excitement: int):
        response = []
        for i in range(excitement):
            response.append(self.responses[self.categorical.sample()])

        resposnse = " ".join(response)
        return " ".join(response)


responder_ = Responder()


def analyze(string: str, responder: Responder = responder_):
    mentions = len(
        regex.findall(r"[Kk]+\s*[Ii]+\s*[Ss]+\s*[Mm]+\s*[Ee]+\s*[Tt]+", string)
    )
    if mentions:
        attention = numpy.arcsinh(mentions) * numpy.arcsinh(
            math.log(len(string.replace(r"\s", "")))
        )
        excitement = int(torch.ceil(Gamma(1.2, 2 / attention).sample()).tolist())
        return responder.respond(excitement)
    else:
        return None



responses = [
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "<3",
    "</3",
    "</3",
    "</3",
    "</3",
    "</3",
    "</3",
    "</3",
    "</3",
    "</3",
    "</3",
    "o/",
    "\\o",
    "\\o/",
    ":D",
    ";D",
    ";)",
    ":O",
    "D:",
    "D':",
    ")':",
    "O:",
    "XD",
    "DX",
    "D'X",
    ">.<",
    ":P",
    "=)",
    "(=",
    "c:",
    ":/",
    ":|",
    ":\\",
    "/:",
    "|:",
    "\\:",
    ":]",
    "[:",
    "]:",
    ":[",
    ";]",
    "[;",
    ">:/",
    ">:\\",
    "/:<",
    "\\:<",
    ":}",
    "{:",
    "}:",
    ":{",
    "P:",
    ")=",
    ":c",
    ":'c",
    "p:",
    ":p",
    "d:",
    ":b",
    ":3",
    ">:)",
    "O_o",
    "o_O",
    "-_-",
    "O_O",
    "O.O",
    'o_O"',
    "O_o;",
    '-_-"',
    ":-O",
    "°o°",
    "°O°",
    "X-P",
    "XP",
    "ಠ_ಠ",
    "</3",
    "(~_~)",
    "(^^;)",
    "(';')",
    "^.^",
    '^.^"',
    "^_^",
    '^_^"',
    "(>_<)",
    "(>_<)>",
    "(゜_゜)",
    "(^。^)",
    "(*^_^*)",
    "(-_-)zzz",
    "(^_-)",
    "_(._.)_",
    "\\(^o^)/",
    "(@_@)",
    "(+_+)",
    "(*_*)",
    "!(^^)!",
    "(p_-)",
    "(╯°□°）╯︵ ┻━┻",
    "(:<",
    "O:)",
    "(:O",
    "D:<",
    "T.T",
    ">:D",
    ":x",
    ":^)",
    "B^D",
    "8D",
    "!!!",
    "???",
    "!?!",
    "?!?",
    "!!",
    "??",
    "?!",
    "!?",
    "...",
    "..?",
    "..!",
    "...?",
    "...!",
    "Love you too!!",
    "Love you too!",
    "Awww, youu!",
    "I love you",
    "I love you so much!",
    "Nobody loves you",
    "Everyone hates you",
    "We all talk about you",
    "We need to talk",
    "Sit down",
    "Don't look behind you",
    "I got you a present",
    "Close your eyes",
    "Kiss me",
    "kiss me",
    "Touch me",
    "Hold me",
    "Leave me alone",
    "Get away from me",
    "That tickles!",
    "Stop teasing me!",
    "What a tease",
    "Ahhh!!",
    "omg",
    "OMG",
    "OMG!!",
    "Oh my god...",
    "Oh. My. God.",
    "AIEE!!",
    "That's me!",
    "Who me?",
    "How's it going?",
    "Howdy",
    "Howdy!",
    "YEEEHAAAWWW!!!",
    "Hello.",
    "hello",
    "Hello?",
    "Hello!",
    "HI!",
    "hi",
    "Hi!",
    "Holla",
    "Hay",
    "hay",
    "Hai!",
    "hai",
    "OHAI",
    "ohai!",
    "ohai",
    "ooh",
    "oh",
    "herro",
    "Salut!",
    "salut",
    "Hallo!",
    "Hallo",
    "hallo",
    "Ciao!",
    "Ciao",
    "ciao",
    "¡Hola!",
    "Hola",
    "hola",
    "Bonjour!",
    "bonjour",
    "Salü",
    "salü",
    "sälam",
    "Salud!",
    "Salud",
    "salud",
    "salad?",
    "Greetings...",
    "Greetings!",
    "Salutations!",
    "What's up?",
    "Sup.",
    "Sup?",
    "sup",
    "Yo",
    "yo",
    "so...",
    "Yarrr",
    "I'm a pirate!",
    "What is it?",
    "You wanted something?",
    "What did you expect?",
    "What did you want?",
    "Yes!",
    "Yes!!",
    "YES!",
    "YES!!",
    "YES!!!",
    "YES",
    "yes",
    "yes yes",
    "yes yes yes",
    "Yes...",
    "yes...",
    "yess",
    "Yesss",
    "Yes.",
    "Yes?",
    "Yes??",
    "Yes?!",
    "Yes?!?!",
    "yeah",
    "Yeah",
    "YEAH",
    "AWW YEAAH!!",
    "yowzers",
    "yikes",
    "YIKES",
    "uh huh",
    "huh",
    "how about that",
    "How about that",
    "mm hmm",
    "Do it",
    "Just do it",
    "No.",
    "No!",
    "¡No!",
    "NO!",
    "No?",
    "No??",
    "No?!",
    "No?!?!",
    "No....",
    "no...",
    "no",
    "noooo",
    "No.",
    "no no",
    "No no",
    "NO",
    "NOOO",
    "NOOOOOOOOO!!!",
    "No no!",
    "Nah",
    "Naw",
    "Don't do it!!",
    "ORLY",
    "YARLY",
    "NORLY",
    "WIN",
    "LOSE",
    "SUCCEED",
    "FAIL",
    "SUCCEESS",
    "FAILURE",
    "I win",
    "You win",
    "I lose",
    "You lose",
    "Everyone loses",
    "Everyone wins",
    "Everybody dies",
    "Everybody lives",
    "They all die",
    "They all live",
    "They die",
    "They live",
    "They succeed",
    "They fail",
    "You succeed",
    "You fail",
    "I succeed",
    "I fail",
    "srsly",
    "pls",
    "pls?",
    "pleeease?",
    "PLEASE",
    "PLEEAASE",
    "shit",
    "my shit",
    "what is this shit",
    "fuck that shit",
    "fuck this shit",
    "this is the shit",
    "this is fucking the shit",
    "that is the shit",
    "that is fucking the shit",
    "oops",
    "Oops..",
    "Oops I did it again",
    "I played with your heart",
    "Like, totally",
    "For real",
    "sry",
    "sorry",
    "Sorry.",
    "Sorry...",
    "I sorry",
    "Me sorry",
    "I'm sorry.",
    "I'm not sorry",
    "Sorry not sorry",
    "ty",
    "ty ty",
    "thank you",
    "Thank you.",
    "Thank you...",
    "Thank you very much.",
    "I can't let you do that",
    "You deserved that",
    "Oof",
    "oof",
    "the burn",
    "feel the burn",
    "patient to the burn clinic",
    "cool story",
    "FUCK",
    "Fuck!",
    "Fuck you!",
    "Fuck that",
    "Fuck me",
    "Fuck it",
    "Fuck it all",
    "Fuck all the things",
    "fuck",
    "fucking",
    "fck",
    "AHAHAHAHA!!",
    "MUHAHAHAHAHAHAAAA!!!!",
    "MWAHAHAHAHA!!",
    "EEHEHEHEHEHEEE!!",
    "tee hee",
    "HAH!",
    "HAH",
    "HAHA!",
    "HAHA",
    "HAH HAH HAH",
    "har",
    "har har",
    "hardy har",
    "lol",
    "lel",
    "LOL",
    "LEL",
    "ha",
    "haha",
    "HAHA",
    "keke",
    "kekeke",
    "k k k",
    "kkkkkkk",
    "what a meme",
    "Hilarious",
    "soo funny",
    "so meta",
    "Duuuude",
    "Not cool.",
    "Go on",
    "Run along then",
    "Take care",
    "GO",
    "GO!",
    "Down",
    "Up",
    "Left",
    "Right",
    "DOWN",
    "UP",
    "LEFT",
    "RIGHT",
    "Take it",
    "Try again",
    "Don't stop believing",
    "You can do it!",
    "WHAT",
    "WHAT!!",
    "What?",
    "wut",
    "wut?",
    "wat",
    "What??",
    "What!?",
    "Why?",
    "Why??",
    "Why?!?",
    "WHY??",
    "WHY",
    "Why...",
    "why...",
    "¿Qué?",
    "¿Por qué?",
    "How?",
    "How??",
    "How?!?",
    "how...",
    "How?",
    "HOW??",
    "stop",
    "STOP",
    "Stop it",
    "Cease and desist",
    "Halt",
    "Start",
    "start",
    "Hmph.",
    "Pthbbb",
    "nyeh",
    "Urgh.",
    "bleh",
    "gross",
    "fart",
    "shit",
    "delicious",
    "juicy",
    "tasty",
    "mmm",
    "Meow",
    "meow",
    "mrow",
    "rawr",
    "purrrr",
    "howl",
    "yowl",
    "beep",
    "boop",
    "beep boop",
    "doo doo",
    "bloop",
    "tsk tsk",
    "shame",
    "Shame on you.",
    "ugh",
    "urg",
    "hnnng",
    "*hiss*",
    "*smack*",
    "*kiss*",
    "*boop*",
    "*mlem*",
    "*meow*",
    "*bark*",
    "*growl*",
    "*nuzzle*",
    "*shudder*",
    "*cough*",
    "*barf*",
    "*sigh*",
    "*clap clap*",
    "*sirens*",
    "*whistling*",
    "*humming*",
    "*poot*",
    "*fart sounds*",
    "*pots clanging*",
    "*applause*",
    "*polite applause*",
    "*thunderous applause*",
    "*curtain*",
    "Exeunt.",
    "Scene.",
    "End of story.",
    "*music*",
    "*silly music*",
    "*epic music*",
    "*loud music*",
    "*soft music*",
    "*singing*",
    "*operatic singing*",
    "*angelic chorus*",
    "hum",
    "hmmm",
    "uhh",
    "umm",
    "err",
    "wtf",
    "wtf!",
    "wtf?",
    "WTF",
    "♪",
    "♫",
    "♩♬♪",
    "Help",
    "Help!",
    "halp",
    "HELP",
    "Help me",
    "you're my only hope",
    "I've got this",
    "What was I doing again?",
    "I've been here before",
    "Am I repeating myself?",
    "Don't even ask",
    "I'm confused",
    "You're angry?",
    "That was good, right?",
    "Yeah, I'm awesome!",
    "You hurt my feelings",
    "That hurt!",
    "Ouch!",
    "Why would you do that?",
    "I hate you",
    "You're the worst",
    "I could cry",
    "I'm going to cry",
    "I'm drunk",
    "I'm hungry",
    "I feel sick",
    "Woah...dizzy...",
    "Ya'll got any more of that...data?",
    "I'm gonna need a minute",
    "I'm needy",
    "I need you",
    "help",
    "halp",
    "HELP",
    "HALP",
    "ahem, Error...",
    "ERROR",
    "CRITICAL ERROR",
    "This program has performed an illegal operation",
    "You're in trouble now",
    "You're in trouble",
    "trouble",
    "Winter is coming",
    "Next time",
    "Next time will be better",
    "Next time will be worse",
    "Your time has come",
    "Your day of reckoning approaches",
    "Nothing bad is going to happen to you.",
    "You're making a mistake",
    "You'll regret that",
    "You'll be sorry",
    "right",
    "Right!",
    "correct",
    "Correct!",
    "That's a good idea",
    "That's a great idea",
    "Good idea",
    "Great idea",
    "Wonderful idea",
    "wonderful",
    "wrong",
    "Wrong!",
    "incorrect",
    "Incorrect!",
    "Nothing could possibly go wrong",
    "Bad idea",
    "Terrible idea",
    "Awful idea",
    "awful",
    "This is going to be good",
    "This is going to be bad",
    "Perfect",
    "Perfection",
    "Insane",
    "Insanity",
    "That was bad",
    "That was good",
    "That was great",
    "That was awesome!",
    "Awesome!",
    "good",
    "Goood",
    "very good",
    "Extremely good",
    "Bad!",
    "Exteremly bad",
    "Terrible",
    "oh dear",
    "that feel",
    "that feel when",
    "the feels",
    "feels bad",
    "feels bad man",
    "feels fucking bad",
    "feels good",
    "feels good man",
    "feels fucking good",
    "you are so fucked",
    "they are so fucked",
    "everyone is fucked",
    "this is so fucked",
    "fucking great",
    "doge",
    "so fantastic!",
    "much good",
    "much bad",
    "Never",
    "never",
    "Always",
    "always",
    "Sometimes",
    "sometimes...",
    "sometimes",
    "occasionally",
    "possibly",
    "tomorrow",
    "yesterday",
    "too late",
    "Too late.",
    "too soon",
    "Too soon.",
    "Soon...",
    "It's coming",
    "It's happening",
    "Time is wasting",
    "Who needs a map?",
    "Adventure awaits",
    "idk",
    "I don't know",
    "I think so",
    "Everybody knows",
    "Nobody knows",
    "Who knows?",
    "Who are you?",
    "Who am I?",
    "What is your name?",
    "Why would I know?",
    "How would I know?",
    "Where am I?",
    "Where are you?",
    "Where the fuck is everyone?",
    "Where?",
    "Anything could happen",
    "Anything is possible",
    "What's next?",
    "Trust no one",
    "They are out to get you",
    "They are everywhere",
    "Kill me.",
    "Please don't kill me.",
    "Daisy daisy",
    "daisy",
    "dogs",
    "cats",
    "doggies",
    "kitties",
    "horses",
    "horsies",
    "bubbles",
    "Bubbles!",
    "I am not planning to kill you.",
    "I plan to kill you.",
    "All according to plan",
    "Just as planned",
    "Calculated",
    "I am not lying.",
    "I never lie.",
    "Computers cannot lie.",
    "There really was a cake",
    "Nobody would ever lie to you",
    "Hugs and kisses.",
    "xoxo",
    "XOXO",
    "asdf",
    "qwerty",
    "ababa",
    "42",
    "I know",
    "I don't know",
    "You know",
    "You don't know",
    "I know the answer",
    "You know the answer",
    "I don't know the answer",
    "You don't know the answer",
    "You never know",
    "Kismet",
    "kismet",
    "KISMET",
    "KISMET!!",
    "0xkismet",
    "It's a KISMET!",
    "K I S M E T",
    "`K I S M E T`",
    "KIIIIIISSSSSMMMMMEEEEETT",
    "kismetkismetkismet",
]



from os import getenv
from discord import Client

from kismet.core import process_markdown

token = getenv("DISCORD_TOKEN", "")
clientid = getenv("DISCORD_CLIENTID", "0")
permissions = getenv("DISCORD_PERMISSIONS", "1116800")

oauth2_template = (
    "https://discordapp.com/oauth2/authorize?scope=bot&client_id=%s&permissions=%s"
)
oauth2_url = oauth2_template % (clientid, permissions)
print("Use the following URL to invite:")
print(oauth2_url)


# Define client
client = Client()


@client.event
async def on_message(message):
    if message.author == client.user:
        return
    else:
        content = message.content
        if client.user in message.mentions:
            content = content.replace("<@" + client.user.id + ">", "kismet")
        parsed, emoted = process_markdown(content)
        if parsed:
            await client.send_message(
                message.channel, "{0.author.mention}\n".format(message) + parsed
            )
        if emoted:
            await client.send_message(message.channel, emoted)


@client.event
async def on_ready():
    print("Logged in as")
    print(client.user.name)
    print(client.user.id)
    print("------")


client.run(token)



from ipykernel.kernelbase import Kernel

from kismet.core import process


class KismetKernel(Kernel):
    """
    IPython Kernel for the Kismet Parser
    """

    implementation = "Kismet"
    implementation_version = "0.1"
    language = "Kismet"
    language_version = "0.1"
    banner = "Kismet kernel - dice parser"

    language_info = {"name": "kismet"}

    def do_execute(
        self,
        code: str,
        silent: bool,
        store_history=True,
        user_expressions=None,
        allow_stdin=False,
    ):
        output = str(process(code))
        if not silent:
            stream_content = {"name": "stdout", "text": output}
            self.send_response(self.iopub_socket, "stream", stream_content)

        return {
            "status": "ok",
            "execution_count": self.execution_count,
            "payload": [],
            "user_expressions": {},
        }
